/* $Log: MultiuserToolkit.java,v $
# Revision 1.2  1998/04/30  20:31:18  stuart
# split out generic RemoteToolkit to support both GUI and TUI
#
# Revision 1.1  1997/07/17  02:29:01  stuart
# Initial revision
#
 */
package bmsi.tui;
import java.awt.*;
import java.awt.peer.*;
import java.awt.image.*;
import java.util.Properties;
import java.net.URL;

/** An AWT Toolkit that forwards all methods to the Toolkit for
   the current logged in user.
   @see bmsi.login.UserContext
   @author Stuart D. Gathman
   @version $Id: MultiuserToolkit.java,v 1.2 1998/04/30 20:31:18 stuart Exp stuart $
 */
public class MultiuserToolkit extends Toolkit {
  private static UserInterface userInterface;

  public static synchronized void setUserInterface(UserInterface u) {
    if (userInterface != null)
      throw new SecurityException(
	"UserInterface already set for MultiuserToolkit");
    userInterface = u;
  }

  /** Find the real toolkit for the currently running session. */
  private RemoteToolkit getToolkit() {
    RemoteToolkit tk =  userInterface.getToolkit();
    if (tk == null)
      throw new RuntimeException("AWT not enabled for this user session");
    return tk;
  }

  // forward java.awt.Toolkit calls to the real toolkit

  protected ButtonPeer createButton(Button b) {
    return getToolkit().createButton(b);
  }
  protected TextFieldPeer createTextField(TextField t) {
    return getToolkit().createTextField(t);
  }
  protected LabelPeer createLabel(Label l) {
    return getToolkit().createLabel(l);
  }
  protected ListPeer createList(List l) {
    return getToolkit().createList(l);
  }
  protected CheckboxPeer createCheckbox(Checkbox cb) {
    return getToolkit().createCheckbox(cb);
  }
  protected ScrollbarPeer createScrollbar(Scrollbar sb) {
    return getToolkit().createScrollbar(sb);
  }
  protected ScrollPanePeer createScrollPane(ScrollPane sp) {
    return getToolkit().createScrollPane(sp);
  }
  protected TextAreaPeer createTextArea(TextArea ta) {
    return getToolkit().createTextArea(ta);
  }
  protected ChoicePeer createChoice(Choice c) {
    return getToolkit().createChoice(c);
  }
  protected FramePeer createFrame(Frame f) {
    return getToolkit().createFrame(f);
  }
  protected CanvasPeer createCanvas(Canvas c) {
    return getToolkit().createCanvas(c);
  }
  protected PanelPeer createPanel(Panel p) {
    return getToolkit().createPanel(p);
  }
  protected WindowPeer createWindow(Window c) {
    return getToolkit().createWindow(c);
  }
  protected DialogPeer createDialog(Dialog c) {
    return getToolkit().createDialog(c);
  }
  protected MenuBarPeer createMenuBar(MenuBar c) {
    return getToolkit().createMenuBar(c);
  }
  protected MenuPeer createMenu(Menu c) {
    return getToolkit().createMenu(c);
  }
  protected PopupMenuPeer createPopupMenu(PopupMenu c) {
    return getToolkit().createPopupMenu(c);
  }
  protected MenuItemPeer createMenuItem(MenuItem c) {
    return getToolkit().createMenuItem(c);
  }
  protected FileDialogPeer createFileDialog(FileDialog c) {
    return getToolkit().createFileDialog(c);
  }
  protected CheckboxMenuItemPeer createCheckboxMenuItem(CheckboxMenuItem c) {
    return getToolkit().createCheckboxMenuItem(c);
  }
  protected FontPeer getFontPeer(String f, int sz) {
    return getToolkit().getFontPeer(f,sz);
  }
  public Dimension getScreenSize() { return getToolkit().getScreenSize(); }
  public int getScreenResolution() {
    return getToolkit().getScreenResolution();
  }
  public ColorModel getColorModel() { return getToolkit().getColorModel(); }
  public String getFontList()[] { return getToolkit().getFontList(); }
  public FontMetrics getFontMetrics(Font f) {
    return getToolkit().getFontMetrics(f);
  }
  public void sync() { getToolkit().sync(); }
  public Image getImage(String s) { return getToolkit().getImage(s); }
  public Image getImage(URL u) { return getToolkit().getImage(u); }
  public boolean prepareImage(Image i, int w, int h, ImageObserver o) {
    return getToolkit().prepareImage(i,w,h,o);
  }
  public int checkImage(Image i, int w, int h, ImageObserver o) {
    return getToolkit().checkImage(i,w,h,o);
  }
  public Image createImage(ImageProducer p) {
    return getToolkit().createImage(p);
  }
  public Image createImage(byte[] b) {
    return getToolkit().createImage(b);
  }
  public Image createImage(byte[] b, int s, int e) {
    return getToolkit().createImage(b,s,e);
  }
  public PrintJob getPrintJob(Frame f, String s, Properties p) {
    return getToolkit().getPrintJob(f,s,p);
  }
  public void beep() { getToolkit().beep(); }
  public java.awt.datatransfer.Clipboard getSystemClipboard() {
    return getToolkit().getSystemClipboard();
  }
  public int getMenuShortcutKeyMask() {
    return getToolkit().getMenuShortcutKeyMask();
  }
  protected EventQueue getSystemEventQueueImpl() {
    return getToolkit().getSystemEventQueueImpl();
  }
}
