package bmsi.tui;
import java.awt.*;
import java.awt.event.*;
import java.awt.peer.*;
import java.io.IOException;

class TUIScrollbar extends TUIComponent implements ScrollbarPeer {
  private int pageinc, lineinc, value;
  private boolean vertical;
  TUIScrollbar(Scrollbar sb,TUIKit toolkit) { super(sb,toolkit); }
  protected void create(TUIContainer parent) {
    Scrollbar sb = (Scrollbar)target;
    vertical = sb.getOrientation() == Scrollbar.VERTICAL;
    if (vertical)
      winID = toolkit.createRemotePeer(parent,NEWVERTSCROLL,this);
    else
      winID = toolkit.createRemotePeer(parent,NEWHORZSCROLL,this);
  }

  protected void initialize() {
    Scrollbar sb = (Scrollbar)target;
    setValues(sb.getValue(),sb.getVisibleAmount(),
		sb.getMinimum(),sb.getMaximum());
    setPageIncrement(sb.getBlockIncrement());
    setLineIncrement(sb.getUnitIncrement());
    super.initialize();
  }

  public void setValues(int val,int vis,int min,int max) {
    value = val;
    toolkit.writeCmd(this,SETVALUES,val,vis,min,max);
  }

  public void setValue(int val) {
    value = val;
    toolkit.writeCmd(this,SETVALUE,val);
  }

  public void setLineIncrement(int i) {
    lineinc = i;
  }

  public void setPageIncrement(int i) {
    pageinc = i;
  }

  /* TUI scrollbars are always 1 char wide (high) */
  public Dimension getMinimumSize() {
    Dimension sz = target.getSize();
    Dimension scale = toolkit.scale(new Dimension(1,1));
    if (vertical)
      sz.width = scale.width;
    else
      sz.height = scale.height;
    return sz;
  }

  private void notifyValue(int type,int newval) {
    Scrollbar sb = (Scrollbar)target;
    sb.setValue(newval);
    toolkit.theQueue.postEvent(new AdjustmentEvent(sb,
      AdjustmentEvent.ADJUSTMENT_VALUE_CHANGED,type,sb.getValue()));
  }
 
  public void remoteMethod(int cmd) throws IOException {
    switch (cmd) {
    case SCROLL_LINEDEC:
      notifyValue(AdjustmentEvent.UNIT_DECREMENT,value-lineinc);
      return;
    case SCROLL_LINEINC:
      notifyValue(AdjustmentEvent.UNIT_INCREMENT,value+lineinc);
      return;
    case SCROLL_PAGEDEC:
      notifyValue(AdjustmentEvent.BLOCK_DECREMENT,value-pageinc);
      return;
    case SCROLL_PAGEINC:
      notifyValue(AdjustmentEvent.BLOCK_INCREMENT,value+pageinc);
      return;
    case SETVALUE:
      notifyValue(AdjustmentEvent.TRACK,toolkit.readShort());
      return;
    }
    super.remoteMethod(cmd);
  }
}
