package bmsi.tui;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.TextEvent;
import java.awt.peer.*;
import java.awt.image.*;
import java.io.*;

// Text component peers -

abstract class TUITextComponent extends TUIComponent
  implements TextComponentPeer
{
  /** txt is not null if and only if it contains a current copy of the
   text.  When the remote client modifies a TextComponent, it sends
   a SETMODIFIED message. */
  protected String txt = null;
  protected int selectBegin = 0;
  protected int selectEnd = 0;
  protected int cols = 0;
  TUITextComponent(TextComponent t,TUIKit toolkit) { super(t,toolkit); }
  protected void initialize() {
    TextComponent c = (TextComponent)target;
    select(c.getSelectionStart(),c.getSelectionEnd());
    String txt = c.getText();
    if (txt != null)
      setText(txt);
    if (c.isEditable())
      setEditable(true);
    super.initialize();
  }

  /** Set the maximum character columns for a TextComponent.  For a TextArea,
      this turns on word wrap.  For a TextField, this restricts input.
      A value of 0 turns off the columns restriction.  For a TextArea, turning
      on the horizontal scrollbar sets columns to 0.  We do not implement
      maximum rows for TextArea yet.
      <p>
      FIXME: The AWT does not inform us when columns (or rows) changes.  
      Perhaps we should check for changes on repaint().
   */
  protected void setColumns(int c) {
    if (c != cols) {
      cols = c;
      toolkit.writeCmd(this,SETCOLUMNS,cols);
    }
  }

  public int getSelectionEnd() { return selectEnd; }
  public int getSelectionStart() { return selectBegin; }

  public void remoteMethod(int cmd) throws IOException {
    switch (cmd) {
    case MENUPICK:
      toolkit.theQueue.postEvent(
        //new Event(target,Event.ACTION_EVENT,getText())
	new ActionEvent(target,ActionEvent.ACTION_PERFORMED,
	getText())
      );
      return;
    case SETMODIFIED:
      // TextEvent introduced in JDK1.1b3
      toolkit.theQueue.postEvent(
	new TextEvent(target,TextEvent.TEXT_VALUE_CHANGED));
      txt = null;
      return;
    case SELECT:
      // SELECT arguments should really be 4 bytes, but keep in mind
      // that our current String format is restricted to 64K as well.
      selectBegin = toolkit.readUnsignedShort();
      selectEnd = toolkit.readUnsignedShort();
      return;
    }
    super.remoteMethod(cmd);
  }

  /** Get the current text value.  Use our local copy unless we have
   received a SETMODIFIED message. */
  synchronized public String getText() {
    if (txt == null) {
      toolkit.writeCmd(this,GETTEXT);
      txt = toolkit.getStringRet();
    }
    return txt;
  }

  public void select(int start,int end) {
    selectBegin = start;
    selectEnd = end;
    toolkit.writeCmd(this,SELECT,start,end);
  }
  public void setCaretPosition(int pos) {
    select(pos,pos);
  }
  public int getCaretPosition() { return getSelectionEnd(); }
  public void setEditable(boolean b) {
    toolkit.writeCmd(this,SETEDITABLE,b ? 1 : 0);
  }
  public void setText(String l) {
    if (l == null) l = "";
    txt = l;
    toolkit.writeCmd(this,SETTEXT,txt);
  }
}
