package bmsi.tui;

import java.awt.*;
import java.awt.event.WindowEvent;
import java.awt.peer.WindowPeer;
import java.io.IOException;

class TUIWindow extends TUIContainer implements WindowPeer {
  private boolean defaultlocation = true;
  TUIWindow(Window w,TUIKit toolkit) { super(w,toolkit); }
  protected void create(TUIContainer parent) {
    winID = toolkit.createRemotePeer(parent,NEWWINDOW,this);
    toolkit.theQueue.postEvent(
      new WindowEvent((Window)target,WindowEvent.WINDOW_OPENED));
  }
  /** Top level windows must set the default Font.
   */
  protected void initialize() {
    Font f = target.getFont();
    if (f == null) {
      f = new Font(toolkit.getFontList()[0],0,10);
      target.setFont(f);
    }
    super.initialize();
  }
  public void toBack() { toolkit.writeCmd(this,TOBACK); }
  public void toFront() { toolkit.writeCmd(this,TOFRONT); }
  public void remoteMethod(int cmd) throws IOException {
    switch (cmd) {
    case TOFRONT:
      if (toolkit.active != this) {
	if (toolkit.active != null)
	  toolkit.theQueue.postEvent(new WindowEvent(
	    (Window)toolkit.active.target,WindowEvent.WINDOW_DEACTIVATED));
	toolkit.active = this;
      }
      toolkit.theQueue.postEvent(
	new WindowEvent((Window)target,WindowEvent.WINDOW_ACTIVATED));
      return;
    case RESHAPE:
      super.remoteMethod(cmd);
      target.validate();
      return;
    case DISPOSE:
      //JDK1.0: target.postEvent(new Event(this,Event.WINDOW_DESTROY,null));
      toolkit.theQueue.postEvent(
	new WindowEvent((Window)target,WindowEvent.WINDOW_CLOSING));
      //target.removeNotify();
      return;
    }
    super.remoteMethod(cmd);
  }

  /** For top level windows, location on screen is just component location. */
  public Point getLocationOnScreen() { return target.getLocation(); }

  public synchronized void setVisible(boolean vis) {
    super.setVisible(vis);
    if (vis) {
      toolkit.sync();
    }
    else if (toolkit.active == this) {
      toolkit.theQueue.postEvent(new WindowEvent(
	(Window)toolkit.active.target,WindowEvent.WINDOW_DEACTIVATED));
      toolkit.active = null;
    }
  }

  public void setBounds(int x,int y,int w,int h) {
    /* Most apps put top level windows at top left of screen.  This
       heuristic tries to fix this ugliness by centering when
       the first location set is 0,0. */
    if (defaultlocation && x == 0 && y == 0) {
      defaultlocation = false;
      Container parent = target.getParent();
      Dimension sz = (parent != null)
		     ? parent.getSize() : toolkit.getScreenSize();
      if (sz.width > w && sz.height > h) {
	x = (sz.width - w)/2;
	y = (sz.height - h)/2;
      }
    }
    /*
    Insets i = getInsets();
    // Our TUI system sets and reports client area size, not total window size.
    super.setBounds(x+i.left,y+i.top,w-i.left-i.right,h-i.top-i.bottom);
    */
    super.setBounds(x,y,w,h);
  }
}
